//index.js
const net = require("../../utils/net.js");
const util = require("../../utils/util.js");
const { api_news_list, api_category_list } = require("../../utils/api.js");
Page({
  data: {
    newList: [],
    scrollH: 500,
    categoryList: [],
    pageArr: [],
    limit: 20,
    categoryId: null,
    selectTab: 0,
    historyObj: {},
    scrollTop: 0,
  },

  onLoad: function () {
    this.loadNewsData({ isRefresh: true });
    this.loadCategoryListData();
    this.getScrollH();
    this.getStorageHistoryObj();
  },
  getScrollH() {
    const _this = this;
    wx.createSelectorQuery()
      .select("#navBar")
      .boundingClientRect(function (res) {
        const sys = wx.getSystemInfoSync();
        _this.setData({
          scrollH: sys.windowHeight - res.height,
        });
      })
      .exec();
  },

  loadCategoryListData() {
    let params = {};
    params.url = api_category_list;
    params.data = {};
    net.req(params, true).then(
      (data) => {
        this.setData({
          categoryList: data,
        });
        this.data.categoryId = data[0].id;
      },
      (e) => {
        util.showToast({ title: e.msg || "" });
      }
    );
  },

  handleTabAction(e) {
    const { index } = e.detail;
    const { categoryId } = this.data;
    const selectCategoryId = this.data.categoryList[index].id;
    if (selectCategoryId != categoryId) {
      this.data.categoryId = selectCategoryId;
      this.data.pageArr[index] = 1;
      this.setData({
        selectTab: index,
        scrollTop: 0,
      });
      // if (!newList[index] || !newList[index].length) {
      this.loadNewsData({ isRefresh: true });
      // }
    }
  },

  getStorageHistoryObj() {
    // 在组件实例进入页面节点树时执行
    let historyObj = wx.getStorageSync("LOOKHISTORY");
    try {
      historyObj = JSON.parse(historyObj);
    } catch (error) {
      historyObj = {};
    } finally {
      this.setData({
        historyObj: historyObj,
      });
    }
  },

  loadNewsData(obj) {
    const { pageArr, limit, newList, categoryId, selectTab } = this.data;
    const page = pageArr[selectTab] ? pageArr[selectTab] : 1;
    let params = {};
    params.url = api_news_list;
    params.data = {
      page: page,
      limit: limit,
    };
    const list = newList[selectTab] || [];
    const len = list.length;
    categoryId && (params.data.categoryId = categoryId);
    if (!obj.isRefresh && len) {
      params.data.lastId = list[len - 1].id;
    }
    // !len &&
    //   wx.showLoading({
    //     title: "数据加载中...",
    //   });
    net.req(params, true).then(
      (data) => {
        if (obj.isRefresh) {
          this.setData({
            [`newList[${selectTab}]`]: data.list,
          });
          this._refresh = false;
        } else {
          if (data.list.length) {
            this.setData({
              [`newList[${selectTab}]`]: newList[selectTab].concat(data.list),
            });
          }
          this._isload = false;
        }
        // wx.hideLoading();
      },
      (e) => {
        // wx.hideLoading();
        obj.isRefresh ? (this._refresh = false) : (this._isload = false);
      }
    );
  },

  /**
   * scroll-view下拉触底事件的处理函数
   */
  scrollToUpper() {
    // if (this._refresh) return;
    // this._refresh = true;
    // const { selectTab, pageArr } = this.data;
    // pageArr[selectTab] = 1;
    // this.loadNewsData({ isRefresh: true });
  },
  /**
   * scroll-view上拉触底事件的处理函数
   */
  scrollToLower() {
    const { selectTab, pageArr } = this.data;
    if (this._isload) return;
    this._isload = true;
    const value = pageArr[selectTab] ? pageArr[selectTab] : 1;
    pageArr[selectTab] = value + 1;
    this.loadNewsData({ isRefresh: false });
  },
});
