// pages/my/my.js
const utils = require("../../utils/util");
const net = require("../../utils/net.js");
const { api_wx_login, api_material_history } = require("../../utils/api.js");
Page({
  /**
   * 页面的初始数据
   */
  data: {
    userInfo: null,
    listData: [],
    hasNohistory: false,
  },
  pageData: {
    wxCode: "",
    page: 1,
    limit: 20,
  },

  /**
   * 生命周期函数--监听页面加载
   */
  onLoad: function () {
    const userInfo = utils.getStorageSync("USERINFO");
    if (userInfo && userInfo.token) {
      this.setData({
        userInfo: userInfo,
      });
      this._onLoad = true;
      this.getSeeHistoryData({ isRefresh: true });
    }
  },

  // 下拉刷新
  onPullDownRefresh: function () {
    if (this.data.userInfo) {
      this.getSeeHistoryData({ isRefresh: true });
    } else {
      wx.stopPullDownRefresh();
    }
  },

  /**
   * 页面上拉触底事件的处理函数
   */
  onReachBottom: function () {
    this.getSeeHistoryData({ isRefresh: false });
  },

  onPageScroll(res) {
    this._scrollTop = res.scrollTop;
  },

  onTabItemTap(item) {
    if (this._onLoad) {
      this._onLoad = false;
    } else {
      const { listData } = this.data;
      if (item.pagePath == "pages/my/my" && this.data.userInfo) {
        this.getSeeHistoryData({ isRefresh: true, limit: listData.length });
      }
    }
  },

  getSeeHistoryData(obj) {
    const { limit } = this.pageData;
    const { listData } = this.data;
    let params = {};
    params.url = api_material_history;
    params.data = {
      page: 1,
      limit: obj.limit || limit,
    };

    const len = listData.length;
    !obj.isRefresh && len && (params.data.lastId = listData[len - 1].historyId);
    net.req(params, true).then(
      (data) => {
        if (obj.isRefresh) {
          if (data.list.length) {
            this.setData(
              {
                listData: data.list,
                hasNohistory: false,
              },
              () => {
                if (obj.limit) {
                  if (this._scrollTop > 0) {
                    setTimeout(() => {
                      wx.pageScrollTo({
                        scrollTop: this._scrollTop,
                        duration: 0,
                      });
                    }, 300);
                  }
                }
              }
            );
          } else {
            this.setData({
              hasNohistory: !listData.length,
            });
          }
          wx.stopPullDownRefresh();
        } else {
          if (data.list.length) {
            this.setData({
              listData: listData.concat(data.list),
            });
          }
        }
      },
      (e) => {
        this.setData({
          hasNohistory: !listData.length,
        });
        wx.stopPullDownRefresh();
        // wx.hideLoading();
      }
    );
  },

  getPhoneNumber: function (e) {
    let { encryptedData, iv } = e.detail;
    if (!encryptedData || !iv) {
      return false;
    }
    let goNext = () => {
      wx.login({
        success: (res) => {
          let { code } = res;
          if (!code) {
            return false;
          }
          this.wxLogin(code, encryptedData, iv);
        },
      });
    };
    wx.checkSession({
      success: () => {
        if (this.pageData.wxCode) {
          this.wxLogin(this.pageData.wxCode, encryptedData, iv);
        } else {
          goNext();
        }
      },
      fail: () => {
        goNext();
      },
    });
  },
  wxLogin(code, encryptedData, iv) {
    let params = {};
    params.url = api_wx_login;
    params.data = {
      code,
      encryptedData,
      iv,
      hooid: "hooli_daily",
      oneEc: "miniP",
      twoEc: "miniP_chum",
      oneSc: "nature",
      twoSc: "nature_search",
    };
    wx.showLoading({
      title: "努力登录中...",
    });
    const shareUid = utils.getStorageSync("SHAREUID");
    if (shareUid && shareUid.length) {
      // 分享用户id
      params.data.shareUid = shareUid;
    }
    net.req(params, true).then(
      (data) => {
        wx.hideLoading();
        if (data && data.userInfo && data.userInfo.token) {
          utils.setStorageSync("USERINFO", data.userInfo);
          this.setData({
            userInfo: data.userInfo,
          });
          this.getSeeHistoryData({ isRefresh: true });
          return false;
        }
      },
      (e) => {
        wx.hideLoading();
      }
    );
  },
  handleGoHomeAction() {
    wx.switchTab({
      url: "/pages/index/index",
    });
  },
});
