// pages/newDetail/newDetail.js
const net = require("../../utils/net.js");
const util = require("../../utils/util.js");
const { api_material_info, api_share_qrCode } = require("../../utils/api.js");
import Poster from "../../utils/poster.js";
Page({
  /**
   * 页面的初始数据
   */
  data: {
    newId: null,
    detailData: null,
    videoLoad: false,
    template: null,
    postImgSrc: null,
    isShowQRPoster: false,
    isShowCanvas: false,
    isShowPostMask: false,
    extendObj: null,
    shareQRImgSrc: null,
    shareQRImgLoad: false,
    poster: null,
    isFullScreen: false,
  },

  /**
   * 生命周期函数--监听页面加载
   */
  onLoad: function (options) {
    const { newId, shareUid, scene } = options;
    if (options && scene) {
      const parmasArr = scene.split("U"); // 通过U区分新闻id跟用户userCode
      if (Array.isArray(parmasArr)) {
        this.data.newId = parmasArr[0];
        this.loadNewDetailData(newId);
        if (parmasArr[1] && parmasArr[1].length) {
          const userCode = "U" + parmasArr[1]; // 拼接用户userCode
          util.setStorageSync("SHAREUID", userCode);
        }
      }
    } else if (options && newId) {
      this.data.newId = newId;
      this.loadNewDetailData(newId);
      if (shareUid && shareUid.length) {
        // 分享用户id
        util.setStorageSync("SHAREUID", shareUid);
      }
    } else {
      util.showToast({ title: "数据维护中,请您稍后再试" });
      setTimeout(function () {
        wx.reLaunch({
          url: "/pages/index/index",
        });
      }, 800);
    }
  },
  /**
   * 用户点击右上角分享
   */
  onShareAppMessage: function () {
    const { detailData } = this.data;
    let path = `/pages/newDetail/newDetail?newId=${this.data.newId}`;
    const userInfo = util.getStorageSync("USERINFO");
    if (userInfo && userInfo.userCode && userInfo.userCode.length) {
      // 分享用户id
      path = path + "&shareUid=" + userInfo.userCode;
    }

    return {
      title: detailData.title,
      path: path,
      imageUrl: detailData.coverImgUrl,
    };
  },

  loadNewDetailData() {
    let params = {};
    params.url = api_material_info;
    params.data = {
      id: this.data.newId,
    };
    net.req(params, true).then(
      (data) => {
        this.setData(
          {
            detailData: data,
            extendObj: {
              coverImg: data.coverImgUrl,
              title: data.title,
            },
          },
          () => {
            this.getBarcode();
            this.setStorageHistoryObj();
          }
        );
      },
      (e) => {
        util.showToast({ title: e.msg || "" });
      }
    );
  },

  setStorageHistoryObj() {
    const { newId } = this.data;
    let historyObj = wx.getStorageSync("LOOKHISTORY");
    try {
      historyObj = JSON.parse(historyObj);
    } catch (error) {
      historyObj = {};
    } finally {
      historyObj[newId] = true;
      wx.setStorageSync("LOOKHISTORY", JSON.stringify(historyObj));
    }
  },

  loadedVideoMetaData(res) {
    this.setData({
      videoLoad: true,
    });
  },

  fullscreenVideochange(res) {
    const fullScreen = res.detail.fullScreen;
    this.setData({
      isFullScreen: fullScreen,
    });
  },

  getBarcode: function () {
    let { newId, detailData } = this.data;
    const userInfo = util.getStorageSync("USERINFO");
    let shareToken = newId;
    if (userInfo && userInfo.userCode && userInfo.userCode.length) {
      shareToken += userInfo.userCode;
    }
    shareToken =
      shareToken.length > 32 ? shareToken.substring(0, 31) : shareToken; // 做容错判断,超过32位
    let params = {};
    params.url = api_share_qrCode;
    const path = detailData.shareObj
      ? detailData.shareObj.path
      : "pages/newDetail/newDetail";
    params.data = {
      scene: shareToken,
      page: path,
      width: 150,
    };
    net
      .req(params, true)
      .then((data) => {
        this.setData({
          postImgSrc: data.qrImg,
        });
      })
      .catch(() => {
        // this.setData({
        //   postImgSrc: "https://discuz.hoolihome.com/defaults/barcode2.jpg",
        // });
      });
  },

  // 富文本
  // htmlParser(obj) {
  //   console.log("htmlParser", obj);
  // },
  // htmlParserLoad(obj) {
  //   console.log("htmlParserLoadhtmlParserLoad", obj);
  // },

  handleGeneratePoster() {
    const { shareQRImgSrc, postImgSrc } = this.data;
    if (shareQRImgSrc) {
      this.setData({
        isShowPostMask: true,
      });
      return;
    } else if (postImgSrc && postImgSrc.length) {
      this.setData(
        {
          isShowQRPoster: true,
        },
        () => {
          wx.showLoading({
            title: "生成海报中...",
          });
        }
      );
    } else {
      util.showToast({ title: "程序员小哥哥努力开发中..." });
    }
  },

  posterCallack: function (arr) {
    if (!arr) return;
    arr.forEach((v, i, a) => {
      let { id, dataset } = v;
      if (id.indexOf("img") !== -1) {
        wx.getImageInfo({
          src: dataset.what,
          success: (res) => {
            v.dataset.uri = res.path;
          },
        });
      }
    });
    if (Array.isArray(arr) && arr.length) {
      this.setData(
        {
          isShowCanvas: true,
          isShowQRPoster: false,
        },
        () => {
          let palette = new Poster().palette(arr);
          this.setData({
            template: palette,
          });
        }
      );
    } else {
      util.showToast({ title: "程序员小哥哥努力开发中..." });
    }
  },

  onImgOK: function (e) {
    const canvasSrc = e.detail.path;
    wx.hideLoading();
    this.setData(
      {
        isShowCanvas: false,
      },
      () => {
        this.setData({
          shareQRImgSrc: canvasSrc,
          isShowPostMask: true,
        });
      }
    );
  },
  saveImgAction: function () {
    const _this = this;
    wx.saveImageToPhotosAlbum({
      filePath: this.data.shareQRImgSrc,
      success(res) {
        wx.showToast({
          title: "保存成功",
          icon: "none",
          duration: 1000,
        });
        _this.setData({
          isShowPostMask: false,
        });
      },
      fail() {
        wx.showModal({
          title: "授权失败",
          content: "是否打开小程序设置界面，完成对该小程序授权状态",
          success: function (res) {
            if (res.confirm) {
              wx.openSetting({
                success(res) {},
              });
            }
          },
        });
      },
    });
  },
  postMaskHide: function () {
    this.setData({
      isShowPostMask: false,
    });
  },

  shareQRImgLoad() {
    this.setData({
      shareQRImgLoad: true,
    });
  },
});
